@@ -575,11 +575,17 @@ on_propdialog_response(GtkDialog * dialog, gint response_id,
                         ui_feedlist_load_selected((nodePtr) ui_data->fp);
                     }
                 }
-
+		#if 0
                 gboolean dn =
                     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
                                                  (ui_data->
                                                   downloadImagesEntry));
+		#endif
+		gboolean dn =
+			hildon_check_button_get_active(GTK_TOGGLE_BUTTON
+							(ui_data->
+							 downloadImagesEntry));
+		
                 if (dn != feed_get_download_images(ui_data->fp))
                     feed_set_download_images(ui_data->fp, dn);
 
@@ -939,8 +945,8 @@ void ui_feed_process_update_result(struct request *request)
                                 SFM_INTERRUPTED;
                             download_cancel_all(TRUE);
                             /* And we need to return sentitivity to add new dialog, so here: */
-                            newdialog_return_to_normal();
-
+                           // newdialog_return_to_normal();
+                           g_idle_add((GSourceFunc)(newdialog_return_to_normal), NULL);
                         } else {
                             ui_feedlist_select((nodePtr) fp);
                             opmlsaved = TRUE;
@@ -1268,9 +1274,14 @@ GtkWidget *ui_feed_propdialog_new(GtkWindow * parent, feedPtr fp)
 
     ui_data->downloadImagesEntry =
         lookup_widget(propdialog, "downloadImagesEntry");
+#if 0
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
                                  (ui_data->downloadImagesEntry),
                                  feed_get_download_images(fp));
+#endif
+    hildon_check_button_set_active(GTK_TOGGLE_BUTTON
+		    		   (ui_data->downloadImagesEntry),
+				   feed_get_download_images(fp));
 
     GtkWidget *subscribedData = lookup_widget(propdialog, "subscribedData");
     gchar *time_str = ui_itemlist_format_date(feed_get_added(fp));
@@ -1299,7 +1310,7 @@ GtkWidget *ui_feed_propdialog_new(GtkWindow * parent, feedPtr fp)
     return propdialog;
 }
 
-void newdialog_return_to_normal()
+gboolean newdialog_return_to_normal(gpointer data)
 {
     g_assert(app_data != NULL);
     g_assert(app_data->app_ui_data != NULL);
@@ -1323,6 +1334,7 @@ void newdialog_return_to_normal()
      	gtk_widget_grab_focus(GTK_WIDGET(app_data->app_ui_data->ui_data->sourceEntry));
      	gtk_entry_set_activates_default(GTK_ENTRY(app_data->app_ui_data->ui_data->sourceEntry), TRUE);
     }     
+	return FALSE;
 }
 
 static gboolean idle_refresh(gpointer data)
