@@ -319,16 +319,29 @@ static gint g_idle_pb_id = 0;
 
 gboolean call_ui_mainwindow_finish(gpointer data)
 {
-    g_idle_id = 0;
-
-    ULOG_DEBUG("Calling ui_mainwindow_finish from idle ....");
-
-    if (app_data && app_data->app_ui_data &&
-        !app_data->app_ui_data->feed_displayed &&
-        !app_data->app_ui_data->nospace)
-        ui_mainwindow_finish();
-
-    return FALSE;
+   if ((app_data->app_ui_data->application_topped == TRUE) && (app_data->app_ui_data->display_off == FALSE))
+  {
+       g_idle_id = 0;
+   
+       ULOG_DEBUG("Calling ui_mainwindow_finish from idle ....");
+   
+       if (app_data && app_data->app_ui_data &&
+           !app_data->app_ui_data->feed_displayed &&
+           !app_data->app_ui_data->nospace)
+       	{
+		 ui_mainwindow_finish();  
+       	}
+   }  
+   else
+   {
+   	if (app_data && app_data->app_ui_data &&
+           !app_data->app_ui_data->feed_displayed &&
+           !app_data->app_ui_data->nospace)
+   	{
+	       app_data->app_ui_data->call_ui_mainwindow_finish_needed = TRUE;	
+   	}
+   }
+   return FALSE;
 }
 
 gboolean call_update_progressbar(gpointer data)
